complete -c taskwarrior-tui -s d -l data -d 'Sets the data folder for taskwarrior-tui' -r
complete -c taskwarrior-tui -s c -l config -d 'Sets the config folder for taskwarrior-tui (currently not used)' -r
complete -c taskwarrior-tui -l taskdata -d 'Sets the .task folder using the TASKDATA environment variable for taskwarrior' -r
complete -c taskwarrior-tui -l taskrc -d 'Sets the .taskrc file using the TASKRC environment variable for taskwarrior' -r
complete -c taskwarrior-tui -s r -l report -d 'Sets default report' -r
complete -c taskwarrior-tui -s h -l help -d 'Print help'
complete -c taskwarrior-tui -s V -l version -d 'Print version'
